# changed so that texture coordinates and real coordinates are no longer the
# same, tex coords are still rectangular cartesian but scale from 0 to 1
# they are now linked to the volume nodes and the texture is oriented
# the same as the skull model

my $x_iso_value;
my $y_iso_value;
my $z_iso_value;
$x_iso_value = 0;
$y_iso_value = 0;
$z_iso_value = 0;

sub set_x_surface {

# remove old surface (hack because as option for naming doesn't work
    gfx modify g_element texture_block iso_surfaces iso_scalar x iso_value $x_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded delete;

# get new iso value
   $x_iso_value= shift(@_);
   print "Setting x iso surface to x = $x_iso_value\n";

   gfx modify g_element texture_block iso_surfaces iso_scalar x iso_value $x_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded;

# set clipping pane position
gfx modify window 1 set current_pane 3;
gfx modify window 1 background colour 0 0 0 texture none;

$x_eye_point = -1000;
$x_near_plane = 800 + $x_iso_value;
$x_far_plane =  1200 + $x_iso_value;
gfx modify window 1 view parallel eye_point $x_eye_point 0 0 interest_point 0 0 0 up_vector 0 0 1 view_angle 23.1014 near_clipping_plane $x_near_plane far_clipping_plane $x_far_plane  relative_viewport ndc_placement -1 1 2 2 viewport_coordinates 0 0 1 1;
gfx modify window 1 overlay scene none;

}
##########################################
sub set_y_surface {

# remove old surface (hack because as option for naming doesn't work
    gfx modify g_element texture_block iso_surfaces iso_scalar y iso_value $y_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded delete;

# get new iso value
   $y_iso_value= shift(@_);
   print "Setting y iso surface to y = $y_iso_value\n";

   gfx modify g_element texture_block iso_surfaces iso_scalar y iso_value $y_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded;

# set clipping pane position
gfx modify window 1 set current_pane 4;
gfx modify window 1 background colour 0 0 0 texture none;

$y_eye_point = -1000;
$y_near_plane = 800 + $y_iso_value;
$y_far_plane =  1200 + $y_iso_value;

gfx modify window 1 view parallel eye_point 0 $y_eye_point 0 interest_point 0 0 0 up_vector 0 0 1 view_angle 23.1014 near_clipping_plane $y_near_plane far_clipping_plane $y_far_plane relative_viewport ndc_placement -1 1 2 2 viewport_coordinates 0 0 1 1;
gfx modify window 1 overlay scene none;


}
#############################################
sub set_z_surface {

# remove old surface (hack because as option for naming doesn't work
    gfx modify g_element texture_block iso_surfaces iso_scalar z iso_value $z_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded delete;

# get new iso value
   $z_iso_value= shift(@_);
   print "Setting z iso surface to z = $z_iso_value\n";

   gfx modify g_element texture_block iso_surfaces iso_scalar z iso_value $z_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded;

# set clipping pane position
gfx modify window 1 set current_pane 2;
gfx modify window 1 background colour 0 0 0 texture none;

$z_eye_point = 1000;
$z_near_plane = 800 - $z_iso_value;
$z_far_plane =  1200 - $z_iso_value;

gfx modify window 1 view parallel eye_point 0 0 $z_eye_point interest_point 0 0 0 up_vector 0 1 0 view_angle 23.1014 near_clipping_plane $z_near_plane far_clipping_plane $z_far_plane relative_viewport ndc_placement -1 1 2 2 viewport_coordinates 0 0 1 1;

gfx modify window 1 overlay scene none;

}

###############################################
# read in mri data and create a volume texture
gfx create texture tract image dcm:images/BIER_Peter_3_000.ima number_pattern 000 number_series 7 262 1 width 1 height 1 depth 1 distortion 0 0 0 colour 0 0 0 alpha 0 decal linear_filter resize_nearest_filter clamp_wrap;

# use linear interpolation
gfx modify texture tract linear

# create a material containing the texture so that we can select along
# with appropriate texture coordinates to visualise the 3D image
gfx create material tract texture tract

# create some useful materials to colour parts of our picture
gfx create material purple ambient 0 0 0 diffuse 0.55 0.35 1 emission 0 0 0 specular 0.5 0.5 0.5 alpha 1 shininess 0.5 
gfx cre mat bluey ambient 0 0.25 0.5 diffuse 0 0.4 1 emission 0 0 0 specular 0.5 0.5 0.5 alpha 1 shininess 0.3

# read in a block to view the texture in, 256mm cube corresponding to 
# the physical size of the scanned region
gfx read nodes texture_block
gfx read elements texture_block


# define the texture coordinates which vary from 0 to 1 along the axes
gfx read nodes tex_coords
gfx read elements tex_coords

# Define the components of the coordinate field as individual scalar
# fields for defining slice planes
gfx define field x component coordinates.x;
gfx define field y component coordinates.y;
gfx define field z component coordinates.z;


# Define the "tex" field to return the red, green and blue components
# of the texture (each on [0,1]) by looking up the texture at the
# position of the "coordinates" field in any element.
# note the coordinates need to match up with the texture coordinates
gfx define field tex sample_texture coordinates tex_coords texture tract minimum 0.0 maximum 1.0;


# Extract several scalar quantities from tex, notably its colour
# components which the user may choose to visualise
gfx define field tex.1 component tex.1;
gfx define field tex.2 component tex.2;
gfx define field tex.3 component tex.3;
gfx define field mag_tex magnitude field tex;
    gfx define field tex_avg sum_components field tex weights 0.333 0.334 0.333;
# Black and white scalar weighting of red, green and blue reflects the
# relative brightness of the three components to our eyes.
gfx define field tex_bw sum_components field tex weights 0.3 0.55 0.15;

# Draw the 3-D texture on the surfaces x = 128.5 and y = 185.5.  The
# .5 makes the slice in the centre of a row of texels.
gfx modify g_element texture_block general clear circle_discretization 6 default_coordinate coordinates element_discretization "1*1*1" native_discretization none;
gfx modify g_element texture_block lines select_on material default selected_material default_selected;
gfx modify g_element texture_block iso_surfaces iso_scalar x iso_value $x_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded;
gfx modify g_element texture_block iso_surfaces iso_scalar y iso_value $y_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded;
gfx modify g_element texture_block iso_surfaces iso_scalar z iso_value $z_iso_value use_elements select_on material tract texture_coordinates tex_coords selected_material default_selected render_shaded;


# Create a 3d window
gfx create window 1
# make it look nice
gfx mod win 1 view perspective
gfx mod win 1 image view_all

gfx modify window 1 layout free_ortho ortho_axes z -y eye_spacing 0.25 width 1078 height 1036;
gfx modify window 1 set current_pane 1;
gfx modify window 1 background colour 0 0 0 texture none;
gfx modify window 1 view perspective eye_point 0 -1000 0 interest_point 0 0 0 up_vector 0 0 1 view_angle 40 near_clipping_plane 800 far_clipping_plane 1200 relative_viewport ndc_placement -1 1 2 2 viewport_coordinates 0 0 1 1;
gfx modify window 1 overlay scene none;
gfx modify window 1 set current_pane 2;
gfx modify window 1 background colour 0 0 0 texture none;
gfx modify window 1 view parallel eye_point 0 0 1000 interest_point 0 0 0 up_vector 0 1 0 view_angle 23.1014 near_clipping_plane 800 far_clipping_plane 1200 relative_viewport ndc_placement -1 1 2 2 viewport_coordinates 0 0 1 1;
gfx modify window 1 overlay scene none;
gfx modify window 1 set current_pane 3;
gfx modify window 1 background colour 0 0 0 texture none;
gfx modify window 1 view parallel eye_point -1000 0 0 interest_point 0 0 0 up_vector 0 0 1 view_angle 23.1014 near_clipping_plane 800 far_clipping_plane 1200 relative_viewport ndc_placement -1 1 2 2 viewport_coordinates 0 0 1 1;
gfx modify window 1 overlay scene none;
gfx modify window 1 set current_pane 4;
gfx modify window 1 background colour 0 0 0 texture none;
gfx modify window 1 view parallel eye_point 0 -1000 0 interest_point 0 0 0 up_vector 0 0 1 view_angle 23.1014 near_clipping_plane 800 far_clipping_plane 1200 relative_viewport ndc_placement -1 1 2 2 viewport_coordinates 0 0 1 1;
gfx modify window 1 overlay scene none;
gfx modify window 1 set transform_tool current_pane 1 std_view_angle 40 normal_lines no_antialias fast_transparency;

#gfx read node iso_block
#gfx read element iso_block
#gfx read node iso_tex_coords
#gfx read element iso_tex_coords

#gfx modify g_element iso_block general clear circle_discretization 6 default_coordinate coordinates element_discretization "32*32*32" native_discretization none;
#gfx modify g_element iso_block iso_surfaces iso_scalar tex.1 iso_value 0.1 use_elements select_on material purple texture_coordinates tex_coords selected_material default_selected render_shaded invisible;


#gfx modify g_element texture_block data_points coordinate coordinates glyph sphere general size "5*5*5" centre 0,0,0 select_on material default selected_material default_selected;
gfx create axes material default_selected length 150;
gfx draw axes;

gfx edit scene;
